@@ -93,6 +93,7 @@ pub struct QueueProposal<'info> {
     #[account(mut)]
     pub transaction: UncheckedAccount<'info>,
     /// The Smart Wallet.
+    #[account(mut)]
     pub smart_wallet: Account<'info, SmartWallet>,
     /// Payer of the queued transaction.
     pub payer: Signer<'info>,
@@ -173,3 +174,13 @@ pub struct CreateProposalMeta<'info> {
     /// System program.
     pub system_program: Program<'info, System>,
 }
+
+/// Accounts for [govern::set_governance_params].
+#[derive(Accounts)]
+pub struct SetGovernanceParams<'info> {
+    /// The [Governor]
+    #[account(mut)]
+    pub governor: Account<'info, Governor>,
+    /// The Smart Wallet.
+    pub smart_wallet: Signer<'info>,
+}
