@@ -1,7 +1,7 @@
 //! Validates accounts structs.
 
 use crate::*;
-use vipers::{assert_keys_eq, invariant, unwrap_int, Validate};
+use vipers::{assert_keys_eq, invariant, unwrap_int, unwrap_opt, Validate};
 
 impl<'info> Validate<'info> for CreateGovernor<'info> {
     fn validate(&self) -> ProgramResult {
@@ -27,15 +27,23 @@ impl<'info> Validate<'info> for ActivateProposal<'info> {
             "proposal must be draft to be activated"
         );
         assert_keys_eq!(self.governor, self.proposal.governor);
-        invariant!(
-            unwrap_int!(
-                (self.proposal.created_at as u64).checked_add(self.governor.params.voting_delay)
-            ) < Clock::get()?.unix_timestamp as u64,
-            VotingDelayNotMet
-        );
-
         assert_keys_eq!(self.electorate, self.governor.electorate);
 
+        let earliest_activation_time = unwrap_int!(self
+            .governor
+            .params
+            .voting_delay
+            .checked_add(self.proposal.created_at as u64));
+        let now = Clock::get()?.unix_timestamp as u64;
+        if earliest_activation_time > now {
+            msg!(
+                "Earliest activation time {}; now: {}",
+                earliest_activation_time,
+                now
+            );
+            invariant!(now >= earliest_activation_time, VotingDelayNotMet);
+        }
+
         Ok(())
     }
 }
@@ -63,10 +71,6 @@ impl<'info> Validate<'info> for CancelProposal<'info> {
 impl<'info> Validate<'info> for QueueProposal<'info> {
     fn validate(&self) -> ProgramResult {
         assert_keys_eq!(self.governor, self.proposal.governor);
-        invariant!(
-            self.proposal.get_state(&self.governor)? == ProposalState::Succeeded,
-            "proposal must be succeeded to be queued"
-        );
         assert_keys_eq!(
             self.governor,
             self.proposal.governor,
@@ -78,6 +82,32 @@ impl<'info> Validate<'info> for QueueProposal<'info> {
             self.governor.smart_wallet,
             "smart wallet should match"
         );
+        let now = Clock::get()?.unix_timestamp;
+        let proposal_state = unwrap_opt!(
+            self.proposal.state(now, self.governor.params.quorum_votes),
+            "invalid state"
+        );
+        if proposal_state != ProposalState::Succeeded {
+            msg!(
+                "now: {}, voting_ends_at: {}",
+                now,
+                self.proposal.voting_ends_at
+            );
+            msg!(
+                "for votes: {}, against votes: {}",
+                self.proposal.for_votes,
+                self.proposal.against_votes,
+            );
+            msg!(
+                "quorum req: {}, abstain votes: {}",
+                self.governor.params.quorum_votes,
+                self.proposal.abstain_votes,
+            );
+            invariant!(
+                proposal_state == ProposalState::Succeeded,
+                "proposal must be succeeded to be queued"
+            );
+        }
         Ok(())
     }
 }
@@ -115,3 +145,14 @@ impl<'info> Validate<'info> for CreateProposalMeta<'info> {
         Ok(())
     }
 }
+
+impl<'info> Validate<'info> for SetGovernanceParams<'info> {
+    fn validate(&self) -> ProgramResult {
+        assert_keys_eq!(
+            self.smart_wallet,
+            self.governor.smart_wallet,
+            "smart wallet should match"
+        );
+        Ok(())
+    }
+}
