@@ -3,6 +3,7 @@
 #![allow(rustdoc::missing_doc_code_examples)]
 
 use anchor_lang::prelude::*;
+use num_traits::cast::ToPrimitive;
 use smart_wallet::SmartWallet;
 use std::convert::TryInto;
 use vipers::invariant;
@@ -12,6 +13,7 @@ use vipers::Validate;
 mod account_structs;
 mod account_validators;
 mod events;
+mod macros;
 pub mod proposal;
 mod state;
 
@@ -119,8 +121,7 @@ pub mod govern {
             .governor
             .params
             .voting_period
-            .try_into()
-            .ok()
+            .to_i64()
             .and_then(|v: i64| now.checked_add(v)));
 
         emit!(ProposalActivateEvent {
@@ -208,6 +209,20 @@ pub mod govern {
         Ok(())
     }
 
+    /// Sets the [GovernanceParameters].
+    /// This may only be called by the [Governor::smart_wallet].
+    #[access_control(ctx.accounts.validate())]
+    pub fn set_governance_params(
+        ctx: Context<SetGovernanceParams>,
+        params: GovernanceParameters,
+    ) -> ProgramResult {
+        msg!("Instruction: set_governor_params");
+
+        ctx.accounts.governor.params = params;
+
+        Ok(())
+    }
+
     /// Creates a [ProposalMeta].
     #[access_control(ctx.accounts.validate())]
     pub fn create_proposal_meta(
