@@ -200,7 +200,9 @@ impl Proposal {
 impl<'info> QueueProposal<'info> {
     /// Queues a Transaction into the Smart Wallet.
     pub fn queue_transaction(&mut self, tx_bump: u8) -> ProgramResult {
-        let cpi_ctx = CpiContext::new(
+        let seeds = governor_seeds!(self.governor);
+        let signer_seeds = &[&seeds[..]];
+        let cpi_ctx = CpiContext::new_with_signer(
             self.smart_wallet_program.to_account_info(),
             smart_wallet::cpi::accounts::CreateTransaction {
                 smart_wallet: self.smart_wallet.to_account_info(),
@@ -209,6 +211,7 @@ impl<'info> QueueProposal<'info> {
                 payer: self.payer.to_account_info(),
                 system_program: self.system_program.to_account_info(),
             },
+            signer_seeds,
         );
 
         // no delay
